@@ -93,7 +93,7 @@ def _get_choice_text(choice):
 
 def _format_group(app, namespace, group_name, group_obj, opt_list):
     group_name = group_name or 'DEFAULT'
-    app.info('[oslo.config] %s %s' % (namespace, group_name))
+    app.debug('[oslo.config] %s %s' % (namespace, group_name))
 
     yield '.. oslo.config:group:: %s' % group_name
     if namespace:
@@ -321,8 +321,9 @@ class ConfigOptXRefRole(XRefRole):
 
 class ConfigGroup(rst.Directive):
 
+    required_arguments = 1
+    optional_arguments = 0
     has_content = True
-
     option_spec = {
         'namespace': directives.unchanged,
     }
@@ -331,14 +332,14 @@ class ConfigGroup(rst.Directive):
         env = self.state.document.settings.env
         app = env.app
 
-        group_name = ' '.join(self.content)
+        group_name = self.arguments[0]
         namespace = self.options.get('namespace')
 
         cached_groups = env.domaindata['oslo.config']['groups']
 
         # Store the current group for use later in option directives
         env.temp_data['oslo.config:group'] = group_name
-        app.info('oslo.config group %s' % group_name)
+        app.debug('oslo.config group %s' % group_name)
 
         # Store the location where this group is being defined
         # for use when resolving cross-references later.
@@ -359,6 +360,9 @@ class ConfigGroup(rst.Directive):
 
         _add(title)
         _add('-' * len(title))
+        _add('')
+        for line in self.content:
+            _add(line)
         node = nodes.section()
         node.document = self.state.document
         nested_parse_with_titles(self.state, result, node)
@@ -380,7 +384,7 @@ class ConfigOption(ObjectDescription):
     def handle_signature(self, sig, signode):
         """Transform an option description into RST nodes."""
         optname = sig
-        self.env.app.info('oslo.config option %s' % optname)
+        self.env.app.debug('oslo.config option %s' % optname)
         # Insert a node into the output showing the option name
         signode += addnodes.desc_name(optname, optname)
         signode['allnames'] = [optname]
